# oslg

Python implementation of the _OSlg_ logger for the OpenStudio SDK.

- PyPi [package](https://pypi.org/project/oslg/)
- Ruby [gem](https://rubygems.org/gems/oslg)
- Ruby GitHub [repository](https://github.com/rd2/oslg)

----

To download the _OSlg_ Python package:

`pip install --upgrade oslg`

----

To import the _OSlg_ module in a Python project:

`from oslg import oslg`

----

To run the _OSlg_ unit tests on a git clone of the repo:

`python -m unittest`
